@@ -20,6 +20,10 @@
  * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
+
 /**
  * SECTION:utils
  * @title: GtkSourceUtils
@@ -138,7 +142,7 @@ gtk_source_utils_unescape_search_text (const gchar *text)
  * See also: gtk_source_utils_unescape_search_text().
  *
  * <warning>
- * The escape and unescape functions are not reciprocal! For example,
+ * Warning: the escape and unescape functions are not reciprocal! For example,
  * escape (unescape (\)) = \\. So avoid cycles such as: search entry -> unescape
  * -> search settings -> escape -> search entry. The original search entry text
  * may be modified.
